@@ -19,4 +19,5 @@ def rotation(angle):
     theta = numpy.radians(angle)
     cos_theta = numpy.cos(theta)
     sin_theta = numpy.sin(theta)
-    return numpy.matrix([[cos_theta, sin_theta], [-sin_theta, cos_theta]])
+
+    return numpy.array([[cos_theta, sin_theta], [-sin_theta, cos_theta]])
